==> otter-0.9.91.tar.gz: otter-browser-0.9.91/src/modules/platforms/windows/WindowsPlatformStyle.h <==
/**************************************************************************
* Otter Browser: Web browser controlled by the user, not vice-versa.
* Copyright (C) 2017 Michal Dutkiewicz aka Emdek <michal@emdek.pl>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
**************************************************************************/

#ifndef OTTER_WINDOWSPLATFORMSTYLE_H
#define OTTER_WINDOWSPLATFORMSTYLE_H

#include "../../../ui/Style.h"

namespace Otter
{

class WindowsPlatformStyle : public Style
{
	Q_OBJECT

public:
	explicit WindowsPlatformStyle(const QString &name);

	void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget = nullptr) const override;
	void drawPrimitive(PrimitiveElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget = nullptr) const override;
	int pixelMetric(PixelMetric metric, const QStyleOption *option = nullptr, const QWidget *widget = nullptr) const override;

protected slots:
	void checkForModernStyle();

private:
	bool m_isModernStyle;
};

}

#endif

==> otter-0.9.99.2.tar.gz: otter-browser-0.9.99.2/src/modules/platforms/windows/WindowsPlatformStyle.h <==
/**************************************************************************
* Otter Browser: Web browser controlled by the user, not vice-versa.
* Copyright (C) 2017 Michal Dutkiewicz aka Emdek <michal@emdek.pl>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
**************************************************************************/

#ifndef OTTER_WINDOWSPLATFORMSTYLE_H
#define OTTER_WINDOWSPLATFORMSTYLE_H

#include "../../../ui/Style.h"

namespace Otter
{

class WindowsPlatformStyle final : public Style
{
	Q_OBJECT

public:
	explicit WindowsPlatformStyle(const QString &name);

	void drawControl(ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget = nullptr) const override;
	void drawPrimitive(PrimitiveElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget = nullptr) const override;
	int pixelMetric(PixelMetric metric, const QStyleOption *option = nullptr, const QWidget *widget = nullptr) const override;
	int getExtraStyleHint(Style::ExtraStyleHint hint) const;

protected slots:
	void checkForModernStyle();

private:
	bool m_isModernStyle;
};

}

#endif
